@@ -13,6 +13,8 @@ extern crate vfs;
 use std::collections::HashMap;
 use std::io;
 
+#[cfg(test)]
+use mockall::{automock, predicate::*};
 use semver::{BuildMetadata, Prerelease, Version};
 use serde::Deserialize;
 use toml_edit::{value, Document};
@@ -28,9 +30,6 @@ pub mod scoop;
 mod version_iter;
 pub mod workflow;
 
-#[cfg(test)] // <-- not needed in integration tests
-extern crate spectral;
-
 #[cfg(test)] // <-- not needed in integration tests
 #[macro_use]
 extern crate mockall;
@@ -38,9 +37,6 @@ extern crate mockall;
 #[cfg(test)] // <-- not needed in integration tests
 extern crate rstest;
 
-#[cfg(test)]
-use mockall::{automock, predicate::*};
-
 pub type AnyError = Box<dyn std::error::Error>;
 pub type Result<T> = core::result::Result<T, AnyError>;
 
@@ -49,10 +45,15 @@ const VERSION: &str = "version";
 const PACK: &str = "package";
 const DEPS: &str = "dependencies";
 
+#[derive(Default, Eq, PartialEq, Debug)]
+pub struct PublishOptions<'a> {
+    pub crate_to_publish: Option<&'a str>,
+    pub all_features: bool,
+}
+
 #[cfg_attr(test, automock)]
 pub trait Publisher {
-    fn publish(&self, path: &str, crt: &str) -> io::Result<()>;
-    fn publish_current(&self, path: &str) -> io::Result<()>;
+    fn publish<'a>(&'a self, path: &'a str, options: PublishOptions<'a>) -> io::Result<()>;
 }
 
 #[cfg_attr(test, automock)]
@@ -205,6 +206,7 @@ struct Package {
 #[serde(untagged)]
 enum Dependency {
     Plain(String),
+    Optional(bool),
     Object(HashMap<String, Dependency>),
     List(Vec<Dependency>),
 }
@@ -235,7 +237,6 @@ pub enum Increment {
 mod tests {
     use super::*;
     use rstest::*;
-    use spectral::prelude::*;
 
     #[rstest]
     #[case::patch(Increment::Patch, "0.1.2")]
@@ -250,7 +251,7 @@ mod tests {
         let actual = increment(v, incr).unwrap();
 
         // Assert
-        assert_that!(actual).is_equal_to(Version::parse(expected).unwrap());
+        assert_eq!(actual, Version::parse(expected).unwrap());
     }
 
     #[test]
@@ -284,6 +285,67 @@ mod tests {
         }
     }
 
+    #[test]
+    fn toml_parse_crate_with_optional_deps() {
+        // Arrange
+        let conf = r#"[package]
+name = "editorconfiger"
+version = "0.1.9"
+description = "Plain tool to validate and compare .editorconfig files"
+authors = ["egoroff <egoroff@gmail.com>"]
+keywords = ["editorconfig"]
+homepage = "https://github.com/aegoroff/editorconfiger"
+edition = "2021"
+license = "MIT"
+
+# See more keys and their definitions at https://doc.rust-lang.org/cargo/reference/manifest.html
+
+[build-dependencies] # <-- We added this and everything after!
+lalrpop = "0.19"
+
+[dependencies]
+lalrpop-util  = { version = "0.19", features = ["lexer"] }
+regex = "1"
+jwalk = "0.6"
+aho-corasick = "0.7"
+nom = "7"
+num_cpus = "1.13.0"
+
+ansi_term = { version = "0.12", optional = true }
+prettytable-rs = { version = "^0.8", optional = true }
+clap = { version = "2", optional = true }
+
+[dev-dependencies]
+table-test = "0.2.1"
+spectral = "0.6.0"
+rstest = "0.12.0"
+
+[features]
+build-binary = ["clap", "ansi_term", "prettytable-rs"]
+
+[[bin]]
+name = "editorconfiger"
+required-features = ["build-binary"]
+
+[profile.release]
+lto = true"#;
+
+        // Act
+        let cfg: CrateConfig = toml::from_str(conf).unwrap();
+
+        // Assert
+        let deps = cfg.dependencies.unwrap();
+        assert_eq!("editorconfiger", cfg.package.name);
+        assert_eq!("0.1.9", cfg.package.version);
+        assert_eq!(9, deps.len());
+        let ansi_term = &deps["ansi_term"];
+        if let Dependency::Object(o) = ansi_term {
+            assert_eq!(2, o.len());
+            assert!(o.contains_key(VERSION));
+            assert!(o.contains_key("optional"));
+        }
+    }
+
     const WKS: &str = r#"
 [workspace]
 
