@@ -1,7 +1,7 @@
 #[macro_use]
 extern crate clap;
 
-use clap::{App, AppSettings, Arg, ArgMatches, SubCommand};
+use clap::{command, ArgMatches, Command};
 use std::option::Option::Some;
 use std::path::PathBuf;
 use vfs::{PhysicalFS, VfsPath};
@@ -15,16 +15,24 @@ use releaser::Increment;
 
 const PATH: &str = "PATH";
 const INCR: &str = "INCR";
+const INCR_HELP: &str = "Version increment. One of the following: major, minor or patch";
+const ALL: &str = "all";
+const ALL_HELP: &str = "Whether to add option --all-features to cargo publish command";
+const OUTPUT: &str = "output";
+const OUTPUT_HELP: &str =
+    "File path to save result to. If not set result will be written into stdout";
+const BASE: &str = "base";
+const BASE_HELP: &str = "Base URI of downloaded artifacts";
 
 fn main() {
     let app = build_cli();
     let matches = app.get_matches();
 
     match matches.subcommand() {
-        ("w", Some(cmd)) => workspace(cmd),
-        ("c", Some(cmd)) => single_crate(cmd),
-        ("b", Some(cmd)) => brew(cmd),
-        ("s", Some(cmd)) => scoop(cmd),
+        Some(("w", cmd)) => workspace(cmd),
+        Some(("c", cmd)) => single_crate(cmd),
+        Some(("b", cmd)) => brew(cmd),
+        Some(("s", cmd)) => scoop(cmd),
         _ => {}
     }
 }
@@ -50,7 +58,7 @@ fn brew(cmd: &ArgMatches) {
     }
 
     let crate_path = cmd.value_of("crate").unwrap_or("");
-    let base_uri = cmd.value_of("base").unwrap_or("");
+    let base_uri = cmd.value_of(BASE).unwrap_or("");
 
     let crate_path: VfsPath = PhysicalFS::new(PathBuf::from(crate_path)).into();
     let linux_path: VfsPath = PhysicalFS::new(PathBuf::from(linux_path)).into();
@@ -64,7 +72,7 @@ fn scoop(cmd: &ArgMatches) {
     let exe_name = cmd.value_of("exe").unwrap_or("");
     let binary_path = cmd.value_of("binary").unwrap_or("");
     let crate_path = cmd.value_of("crate").unwrap_or("");
-    let base_uri = cmd.value_of("base").unwrap_or("");
+    let base_uri = cmd.value_of(BASE).unwrap_or("");
 
     let crate_path: VfsPath = PhysicalFS::new(PathBuf::from(crate_path)).into();
     let binary_path: VfsPath = PhysicalFS::new(PathBuf::from(binary_path)).into();
@@ -83,15 +91,15 @@ fn output_string(cmd: &ArgMatches, s: Option<String>) {
     match s {
         None => std::process::exit(ErrorCode::NoOutputProduced as i32),
         Some(b) => {
-            let output_path = cmd.value_of("output");
+            let output_path = cmd.value_of(OUTPUT);
             match output_path {
-                None => println!("{}", b),
+                None => println!("{b}"),
                 Some(path) => {
                     let result = std::fs::write(path, b);
                     match result {
                         Ok(_) => {}
                         Err(e) => {
-                            eprintln!("{}", e);
+                            eprintln!("{e}");
                             std::process::exit(ErrorCode::FileWriteError as i32);
                         }
                     }
@@ -107,6 +115,7 @@ where
 {
     let path = cmd.value_of(PATH).unwrap();
     let incr = cmd.value_of(INCR).unwrap();
+    let all_features = cmd.is_present(ALL);
 
     let inc = match incr {
         "major" => Some(Increment::Major),
@@ -121,7 +130,7 @@ where
 
     let r: VfsPath = PhysicalFS::new(PathBuf::from(path)).into();
     let root = VPath::new(path, r);
-    match release.release(root, inc.unwrap()) {
+    match release.release(root, inc.unwrap(), all_features) {
         Ok(()) => {}
         Err(e) => {
             eprintln!("Path:\t{}\nError:\t{}", path, e);
@@ -130,143 +139,133 @@ where
     }
 }
 
-fn build_cli() -> App<'static, 'static> {
-    return App::new(crate_name!())
-        .setting(AppSettings::ArgRequiredElseHelp)
+fn build_cli() -> Command<'static> {
+    return command!(crate_name!())
+        .arg_required_else_help(true)
         .version(crate_version!())
-        .author("egoroff <egoroff@gmail.com>")
-        .about("Rust releasing workspace tool")
+        .author(crate_authors!("\n"))
+        .about(crate_description!())
         .subcommand(
-            SubCommand::with_name("w")
+            Command::new("w")
                 .aliases(&["workspace"])
                 .about("Release workspace specified by path")
                 .arg(
-                    Arg::with_name(INCR)
-                        .help("Version increment. One of the following: major, minor or patch")
+                    arg!([INCR])
+                        .help(INCR_HELP)
                         .required(true)
                         .index(1),
                 )
                 .arg(
-                    Arg::with_name(PATH)
+                    arg!([PATH])
                         .help("Sets workspace root path")
                         .required(true)
                         .index(2),
                 )
                 .arg(
-                    Arg::with_name("delay")
-                        .long("delay")
-                        .short("d")
+                    arg!(-d --delay <URI>)
+                        .required(false)
                         .takes_value(true)
                         .default_value("20")
-                        .help("Delay in seconds between publish next workflow's crate")
-                        .required(false),
+                        .help("Delay in seconds between publish next workflow's crate"),
+                )
+                .arg(
+                    arg!(-a --all)
+                        .required(false)
+                        .takes_value(false)
+                        .help(ALL_HELP),
                 ),
         )
         .subcommand(
-            SubCommand::with_name("c")
+            Command::new("c")
                 .aliases(&["crate"])
                 .about("Release single crate specified by path")
                 .arg(
-                    Arg::with_name(INCR)
-                        .help("Version increment. One of the following: major, minor or patch")
+                    arg!([INCR])
+                        .help(INCR_HELP)
                         .required(true)
                         .index(1),
                 )
                 .arg(
-                    Arg::with_name(PATH)
+                    arg!([PATH])
                         .help("Sets crate's root path")
                         .required(true)
                         .index(2),
+                )
+                .arg(
+                    arg!(-a --all)
+                        .required(false)
+                        .takes_value(false)
+                        .help(ALL_HELP),
                 ),
         )
         .subcommand(
-            SubCommand::with_name("b")
+            Command::new("b")
                 .aliases(&["brew"])
                 .about("Create brew package manager Formula (package definition file) to publish it into a tap (MacOS and Linux only)")
                 .arg(
-                    Arg::with_name("crate")
-                        .long("crate")
-                        .short("c")
+                    arg!(-c --crate <PATH>)
+                        .required(true)
                         .takes_value(true)
-                        .help("Sets crate's path where Cargo.toml located")
-                        .required(true),
+                        .help("Sets crate's path where Cargo.toml located"),
                 )
                 .arg(
-                    Arg::with_name("linux")
-                        .long("linux")
-                        .short("l")
+                    arg!(-l --linux <PATH>)
+                        .required(false)
                         .takes_value(true)
-                        .help("Sets Linux package directory path")
-                        .required(false),
+                        .help("Sets Linux package directory path"),
                 )
                 .arg(
-                    Arg::with_name("macos")
-                        .long("macos")
-                        .short("m")
+                    arg!(-m --macos <PATH>)
+                        .required(false)
                         .takes_value(true)
-                        .help("Sets Mac OS package directory path")
-                        .required(false),
+                        .help("Sets Mac OS package directory path"),
                 )
                 .arg(
-                    Arg::with_name("base")
-                        .long("base")
-                        .short("b")
+                    arg!(-b --base <URI>)
+                        .required(true)
                         .takes_value(true)
-                        .help("Base URI of downloaded artifacts")
-                        .required(true),
+                        .help(BASE_HELP),
                 )
                 .arg(
-                    Arg::with_name("output")
-                        .long("output")
-                        .short("u")
+                    arg!(-u --output)
+                        .required(false)
                         .takes_value(true)
-                        .help("File path to save result to. If not set result will be written into stdout")
-                        .required(false),
+                        .help(OUTPUT_HELP),
                 ),
         )
         .subcommand(
-            SubCommand::with_name("s")
+            Command::new("s")
                 .aliases(&["scoop"])
                 .about("Create scoop package manager JSON (package definition file) to publish it into bucket (Windows only)")
                 .arg(
-                    Arg::with_name("crate")
-                        .long("crate")
-                        .short("c")
+                    arg!(-c --crate <PATH>)
+                        .required(true)
                         .takes_value(true)
-                        .help("Sets crate's path where Cargo.toml located")
-                        .required(true),
+                        .help("Sets crate's path where Cargo.toml located"),
                 )
                 .arg(
-                    Arg::with_name("binary")
-                        .long("binary")
-                        .short("i")
+                    arg!(-i --binary <PATH>)
+                        .required(true)
                         .takes_value(true)
-                        .help("Sets 64-bit binary package directory path")
-                        .required(true),
+                        .help("Sets 64-bit binary package directory path"),
                 )
                 .arg(
-                    Arg::with_name("exe")
-                        .long("exe")
-                        .short("e")
+                    arg!(-e --exe <FILE>)
+                        .required(true)
                         .takes_value(true)
-                        .help("Sets Windows executable name")
-                        .required(true),
+                        .help("Sets Windows executable name"),
                 )
                 .arg(
-                    Arg::with_name("base")
-                        .long("base")
-                        .short("b")
+                    arg!(-b --base)
+                        .required(true)
                         .takes_value(true)
-                        .help("Base URI of downloaded artifacts")
-                        .required(true),
+                        .help(BASE_HELP),
                 )
                 .arg(
-                    Arg::with_name("output")
-                        .long("output")
-                        .short("u")
+                    arg!(-u --output)
+                        .required(false)
                         .takes_value(true)
-                        .help("File path to save result to. If not set result will be written into stdout")
-                        .required(false),
+                        .help(OUTPUT_HELP),
                 ),
         );
 }
